# Changelog

All notable changes to this project will be documented in this file.

## [1.0.0] - 2025-11-28
## [1.1.0] - 2025-11-29
## [1.1.1] - 2025-11-30
## [1.1.2] - 2025-12-01
## [1.1.3] - 2025-12-01
## [1.1.4] - 2025-12-02
## [1.1.5] - 2025-12-02
## [1.1.6] - 2025-12-03

### Added
- Initial release
- Order management API
- Shipment tracking API
- Product management API
- Inventory management API
- Webhook integration
